@@ -4,9 +4,9 @@ from sqlalchemy.ext.asyncio import AsyncSession, create_async_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
-from defi_common import config
+from defi_common import dbconfig
 
-DATABASE_URL = config.config.db_url
+DATABASE_URL = dbconfig.db_config.db_url
 
 engine = create_async_engine(DATABASE_URL, echo=False)
 Base = declarative_base()
